/*
 * dbwtech.h --
 *
 * Style information for display.
 * MAXTILESTYLES is the maximum number of styles usable for display
 * of tiles.
 *
 * rcsid $Header: /ufs/repository/magic/dbwind/dbwtech.h,v 1.1.1.1 2000/03/29 18:35:24 rajit Exp $
 */

#ifndef _DBWTECH_H
#define	_DBWTECH_H

extern TileTypeBitMask	*DBWStyleToTypesTbl;

#define	DBWStyleToTypes(s)	(DBWStyleToTypesTbl + s)

/* forward declarations */
int  DBWTechParseStyle();

#endif /* _DBWTECH_H */
